Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(119)

Unified Diff: ui/views/animation/test/test_ink_drop_ripple_observer.h

Issue 1937103003: Rename of InkDropAnimation classes to InkDropRipple. (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: Removed test_ink_drop_animation_observer.h from views.gyp and doc update. Created 4 years, 8 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: ui/views/animation/test/test_ink_drop_ripple_observer.h
diff --git a/ui/views/animation/test/test_ink_drop_animation_observer.h b/ui/views/animation/test/test_ink_drop_ripple_observer.h
similarity index 50%
rename from ui/views/animation/test/test_ink_drop_animation_observer.h
rename to ui/views/animation/test/test_ink_drop_ripple_observer.h
index 12c1d19610164c6b8da70346654288ead9af5bb2..33d5f4abee2462cef0952083324ca975f9a225d6 100644
--- a/ui/views/animation/test/test_ink_drop_animation_observer.h
+++ b/ui/views/animation/test/test_ink_drop_ripple_observer.h
@@ -2,31 +2,30 @@
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.
-#ifndef UI_VIEWS_ANIMATION_TEST_TEST_INK_DROP_ANIMATION_OBSERVER_H_
-#define UI_VIEWS_ANIMATION_TEST_TEST_INK_DROP_ANIMATION_OBSERVER_H_
+#ifndef UI_VIEWS_ANIMATION_TEST_TEST_INK_DROP_RIPPLE_OBSERVER_H_
+#define UI_VIEWS_ANIMATION_TEST_TEST_INK_DROP_RIPPLE_OBSERVER_H_
#include "testing/gtest/include/gtest/gtest.h"
-#include "ui/views/animation/ink_drop_animation_observer.h"
+#include "ui/views/animation/ink_drop_ripple_observer.h"
#include "ui/views/animation/ink_drop_state.h"
#include "ui/views/animation/test/test_ink_drop_animation_observer_helper.h"
namespace views {
-class InkDropAnimation;
+class InkDropRipple;
namespace test {
-// Simple InkDropAnimationObserver test double that tracks if
-// InkDropAnimationObserver methods are invoked and the parameters used for the
-// last invocation.
-class TestInkDropAnimationObserver
- : public InkDropAnimationObserver,
+// Simple InkDropRippleObserver test double that tracks if InkDropRippleObserver
+// methods are invoked and the parameters used for the last invocation.
+class TestInkDropRippleObserver
+ : public InkDropRippleObserver,
public TestInkDropAnimationObserverHelper<InkDropState> {
public:
- TestInkDropAnimationObserver();
- ~TestInkDropAnimationObserver() override;
+ TestInkDropRippleObserver();
+ ~TestInkDropRippleObserver() override;
- void set_ink_drop_animation(InkDropAnimation* ink_drop_animation) {
- ink_drop_animation_ = ink_drop_animation;
+ void set_ink_drop_ripple(InkDropRipple* ink_drop_ripple) {
+ ink_drop_ripple_ = ink_drop_ripple;
}
InkDropState target_state_at_last_animation_started() const {
@@ -37,7 +36,7 @@ class TestInkDropAnimationObserver
return target_state_at_last_animation_ended_;
}
- // InkDropAnimationObserver:
+ // InkDropRippleObserver:
void AnimationStarted(InkDropState ink_drop_state) override;
void AnimationEnded(InkDropState ink_drop_state,
InkDropAnimationEndedReason reason) override;
@@ -46,23 +45,23 @@ class TestInkDropAnimationObserver
// The type this inherits from. Reduces verbosity in .cc file.
using ObserverHelper = TestInkDropAnimationObserverHelper<InkDropState>;
// The value of InkDropAnimation::GetTargetInkDropState() the last time an
// InkDropAnimationStarted() event was handled. This is only valid if
// |ink_drop_animation_| is not null.
InkDropState target_state_at_last_animation_started_;
// The value of InkDropAnimation::GetTargetInkDropState() the last time an
// AnimationEnded() event was handled. This is only valid if
// |ink_drop_animation_| is not null.
InkDropState target_state_at_last_animation_ended_;
- // An InkDropAnimation to spy info from when notifications are handled.
- InkDropAnimation* ink_drop_animation_;
+ // An InkDropRipple to spy info from when notifications are handled.
+ InkDropRipple* ink_drop_ripple_;
- DISALLOW_COPY_AND_ASSIGN(TestInkDropAnimationObserver);
+ DISALLOW_COPY_AND_ASSIGN(TestInkDropRippleObserver);
};
} // namespace test
} // namespace views
-#endif // UI_VIEWS_ANIMATION_TEST_TEST_INK_DROP_ANIMATION_OBSERVER_H_
+#endif // UI_VIEWS_ANIMATION_TEST_TEST_INK_DROP_RIPPLE_OBSERVER_H_
« no previous file with comments | « ui/views/animation/test/test_ink_drop_host.cc ('k') | ui/views/animation/test/test_ink_drop_ripple_observer.cc » ('j') | no next file with comments »

Powered by Google App Engine
@@ -46,23 +45,23 @@ class TestInkDropAnimationObserver
// The type this inherits from. Reduces verbosity in .cc file.
using ObserverHelper = TestInkDropAnimationObserverHelper<InkDropState>;
- // The value of InkDropAnimation::GetTargetInkDropState() the last time an
- // InkDropAnimationStarted() event was handled. This is only valid if
- // |ink_drop_animation_| is not null.
+ // The value of InkDropRipple::GetTargetInkDropState() the last time an
+ // AnimationStarted() event was handled. This is only valid if
+ // |ink_drop_ripple_| is not null.
InkDropState target_state_at_last_animation_started_;
@@ -46,23 +45,23 @@ class TestInkDropAnimationObserver
InkDropState target_state_at_last_animation_started_;
- // The value of InkDropAnimation::GetTargetInkDropState() the last time an
+ // The value of InkDropRipple::GetTargetInkDropState() the last time an
// AnimationEnded() event was handled. This is only valid if
@@ -46,23 +45,23 @@ class TestInkDropAnimationObserver
// AnimationEnded() event was handled. This is only valid if
- // |ink_drop_animation_| is not null.
+ // |ink_drop_ripple_| is not null.
InkDropState target_state_at_last_animation_ended_;
This is Rietveld 408576698